devtools/go.sh: check for go 1.16

Change-Id: If18727eb090f66e68ff153b472b051eaf1a84b3c
Reviewed-on: https://go-review.googlesource.com/c/pkgsite/+/344393
Trust: Jonathan Amsterdam <jba@google.com>
Run-TryBot: Jonathan Amsterdam <jba@google.com>
TryBot-Result: kokoro <noreply+kokoro@google.com>
Reviewed-by: Jamal Carvalho <jamal@golang.org>
diff --git a/devtools/go.sh b/devtools/go.sh
index d5285a0..0ddf0fa 100755
--- a/devtools/go.sh
+++ b/devtools/go.sh
@@ -18,17 +18,16 @@
 
 gocmd="dockercompose run go"
 if type go > /dev/null; then
   # pkgsite requires go1.15 or higher. If that's installed on the machine, just
   # use the local go since it will be faster.
   # kokoro run go1.12.
   #
   # This awk program splits the third whitespace-separated field
   # (e.g. "go1.15.5") on the dot character and prints the second part.
   v=`go version | awk '{split($3, parts, /\./); print parts[2]}'`
-  if (( v >= 15 )); then
+  if (( v >= 16 )); then
     gocmd=go
   fi;
 fi;
 
 $gocmd $@
-
@@ -18,17 +18,16 @@
 gocmd="dockercompose run go"
 if type go > /dev/null; then
-  # pkgsite requires go1.15 or higher. If that's installed on the machine, just
+  # pkgsite requires go1.16 or higher. If that's installed on the machine, just
   # use the local go since it will be faster.
   # kokoro run go1.12.